{
    "$graph": [
        {
            "class": "CommandLineTool",
            "id": "#bwa-mem-SE.cwl",
            "label": "bwa-mem-SE-0.7.12",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biocontainers/bwa:v0.7.12_cv3"
                }
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6300
                }
            ],
            "baseCommand": [
                "bwa",
                "mem"
            ],
            "inputs": [
                {
                    "id": "#bwa-mem-SE.cwl/bwa-mem-SE-0.7.12/reference",
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "inputBinding": {
                        "position": 4
                    },
                    "doc": "FastA file for reference genome",
                    "secondaryFiles": [
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa"
                    ]
                },
                {
                    "id": "#bwa-mem-SE.cwl/bwa-mem-SE-0.7.12/RG_ID",
                    "type": "string",
                    "doc": "Read group identifier (ID) in RG line"
                },
                {
                    "id": "#bwa-mem-SE.cwl/bwa-mem-SE-0.7.12/RG_PL",
                    "type": "string",
                    "doc": "Platform/technology used to produce the read (PL) in RG line"
                },
                {
                    "id": "#bwa-mem-SE.cwl/bwa-mem-SE-0.7.12/RG_PU",
                    "type": "string",
                    "doc": "Platform Unit (PU) in RG line"
                },
                {
                    "id": "#bwa-mem-SE.cwl/bwa-mem-SE-0.7.12/RG_LB",
                    "type": "string",
                    "doc": "DNA preparation library identifier (LB) in RG line"
                },
                {
                    "id": "#bwa-mem-SE.cwl/bwa-mem-SE-0.7.12/RG_SM",
                    "type": "string",
                    "doc": "Sample (SM) identifier in RG line"
                },
                {
                    "id": "#bwa-mem-SE.cwl/bwa-mem-SE-0.7.12/fq",
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "inputBinding": {
                        "position": 5
                    },
                    "doc": "FastQ file from next-generation sequencers"
                },
                {
                    "id": "#bwa-mem-SE.cwl/bwa-mem-SE-0.7.12/nthreads",
                    "type": "int",
                    "inputBinding": {
                        "prefix": "-t",
                        "position": 3
                    },
                    "doc": "number of cpu cores to be used"
                },
                {
                    "id": "#bwa-mem-SE.cwl/bwa-mem-SE-0.7.12/outprefix",
                    "type": "string"
                }
            ],
            "stdout": "$(inputs.outprefix).sam",
            "stderr": "$(inputs.outprefix).sam.log",
            "arguments": [
                {
                    "position": 1,
                    "prefix": "-K",
                    "valueFrom": "10000000"
                },
                {
                    "position": 2,
                    "prefix": "-R",
                    "valueFrom": "@RG\tID:$(inputs.RG_ID)\tPL:$(inputs.RG_PL)\tPU:$(inputs.RG_PU)\tLB:$(inputs.RG_LB)\tSM:$(inputs.RG_SM)"
                }
            ],
            "outputs": [
                {
                    "id": "#bwa-mem-SE.cwl/bwa-mem-SE-0.7.12/sam",
                    "type": "File",
                    "format": "http://edamontology.org/format_2573",
                    "outputBinding": {
                        "glob": "$(inputs.outprefix).sam"
                    }
                },
                {
                    "id": "#bwa-mem-SE.cwl/bwa-mem-SE-0.7.12/log",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.outprefix).sam.log"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#picard-SortSam.cwl",
            "label": "picard-SortSam-2.10.6",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/picard:2.10.6--py27_0"
                }
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6300
                }
            ],
            "baseCommand": [
                "java",
                "-jar",
                "/usr/local/share/picard-2.10.6-0/picard.jar",
                "SortSam"
            ],
            "inputs": [
                {
                    "id": "#picard-SortSam.cwl/picard-SortSam-2.10.6/sam",
                    "type": "File",
                    "format": "http://edamontology.org/format_2573",
                    "inputBinding": {
                        "prefix": "INPUT=",
                        "position": 1
                    },
                    "doc": "input SAM alignment file"
                },
                {
                    "id": "#picard-SortSam.cwl/picard-SortSam-2.10.6/outprefix",
                    "type": "string"
                }
            ],
            "outputs": [
                {
                    "id": "#picard-SortSam.cwl/picard-SortSam-2.10.6/bam",
                    "type": "File",
                    "format": "http://edamontology.org/format_2572",
                    "outputBinding": {
                        "glob": "$(inputs.outprefix).bam"
                    }
                },
                {
                    "id": "#picard-SortSam.cwl/picard-SortSam-2.10.6/log",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.outprefix).bam.log"
                    }
                }
            ],
            "stderr": "$(inputs.outprefix).bam.log",
            "arguments": [
                {
                    "position": 2,
                    "valueFrom": "OUTPUT=$(inputs.outprefix).bam"
                },
                {
                    "position": 3,
                    "valueFrom": "TMP_DIR=$(inputs.outprefix).bam.temp"
                },
                {
                    "position": 4,
                    "valueFrom": "SORT_ORDER=coordinate"
                },
                {
                    "position": 5,
                    "valueFrom": "COMPRESSION_LEVEL=1"
                },
                {
                    "position": 6,
                    "valueFrom": "VALIDATION_STRINGENCY=LENIENT"
                }
            ]
        },
        {
            "class": "Workflow",
            "id": "#main",
            "label": "fastqSE2bam",
            "inputs": [
                {
                    "type": "string",
                    "doc": "Read group identifier (ID) in RG line",
                    "id": "#main/RG_ID"
                },
                {
                    "type": "string",
                    "doc": "DNA preparation library identifier (LB) in RG line",
                    "id": "#main/RG_LB"
                },
                {
                    "type": "string",
                    "doc": "Platform/technology used to produce the read (PL) in RG line",
                    "id": "#main/RG_PL"
                },
                {
                    "type": "string",
                    "doc": "Platform Unit (PU) in RG line",
                    "id": "#main/RG_PU"
                },
                {
                    "type": "string",
                    "doc": "Sample (SM) identifier in RG line",
                    "id": "#main/RG_SM"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "doc": "FastQ file from next-generation sequencers",
                    "id": "#main/fq"
                },
                {
                    "type": "int",
                    "doc": "number of cpu cores to be used",
                    "id": "#main/nthreads"
                },
                {
                    "type": "string",
                    "doc": "Output prefix name",
                    "id": "#main/outprefix"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "doc": "FastA file for reference genome",
                    "secondaryFiles": [
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa"
                    ],
                    "id": "#main/reference"
                }
            ],
            "steps": [
                {
                    "label": "bwa_mem_SE",
                    "doc": "Mapping onto reference using BWA MEM",
                    "run": "#bwa-mem-SE.cwl",
                    "in": [
                        {
                            "source": "#main/RG_ID",
                            "id": "#main/bwa_mem_SE/RG_ID"
                        },
                        {
                            "source": "#main/RG_LB",
                            "id": "#main/bwa_mem_SE/RG_LB"
                        },
                        {
                            "source": "#main/RG_PL",
                            "id": "#main/bwa_mem_SE/RG_PL"
                        },
                        {
                            "source": "#main/RG_PU",
                            "id": "#main/bwa_mem_SE/RG_PU"
                        },
                        {
                            "source": "#main/RG_SM",
                            "id": "#main/bwa_mem_SE/RG_SM"
                        },
                        {
                            "source": "#main/fq",
                            "id": "#main/bwa_mem_SE/fq"
                        },
                        {
                            "source": "#main/nthreads",
                            "id": "#main/bwa_mem_SE/nthreads"
                        },
                        {
                            "source": "#main/outprefix",
                            "id": "#main/bwa_mem_SE/outprefix"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/bwa_mem_SE/reference"
                        }
                    ],
                    "out": [
                        "#main/bwa_mem_SE/sam",
                        "#main/bwa_mem_SE/log"
                    ],
                    "id": "#main/bwa_mem_SE"
                },
                {
                    "label": "picard_SortSam",
                    "doc": "Sort sam file and save as bam file",
                    "run": "#picard-SortSam.cwl",
                    "in": [
                        {
                            "source": "#main/outprefix",
                            "id": "#main/picard_SortSam/outprefix"
                        },
                        {
                            "source": "#main/bwa_mem_SE/sam",
                            "id": "#main/picard_SortSam/sam"
                        }
                    ],
                    "out": [
                        "#main/picard_SortSam/bam",
                        "#main/picard_SortSam/log"
                    ],
                    "id": "#main/picard_SortSam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2572",
                    "outputSource": "#main/picard_SortSam/bam",
                    "id": "#main/bam"
                },
                {
                    "type": "File",
                    "outputSource": "#main/picard_SortSam/log",
                    "id": "#main/bam_log"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2573",
                    "outputSource": "#main/bwa_mem_SE/sam",
                    "id": "#main/sam"
                },
                {
                    "type": "File",
                    "outputSource": "#main/bwa_mem_SE/log",
                    "id": "#main/sam_log"
                }
            ]
        }
    ],
    "cwlVersion": "v1.0",
    "$namespaces": {
        "edam": "http://edamontology.org/"
    }
}
